==> v1.1.5.zip: disapp/app/src/main/java/org/disroot/disrootapp/utils/Constants.java <==
package org.disroot.disrootapp.utils;

/**
 * Created by jackson on 02/11/15.
 */
public class Constants {
    public static final long SPLASH_SCREEN_DURATION = 3000;
    public static final long SPLASH_SCREEN_INTERVAL = 1000;


    public static final String title_activity_state = "StateActivity";
    public static final String URL_DisApp_FORUM = "https://forum.disroot.org/";
    public static final String URL_DisApp_CALC = "https://calc.disroot.org";
    public static final String URL_DisApp_BIN = "https://bin.disroot.org";
    public static final String URL_DisApp_UPLOAD = "https://upload.disroot.org";
    public static final String URL_DisApp_SEARX = "https://search.disroot.org";
    public static final String URL_DisApp_POLL = "https://poll.disroot.org";
    public static final String URL_DisApp_BOARD = "https://board.disroot.org";
    public static final String URL_DisApp_USER = "https://user.disroot.org";
    public static final String URL_DisApp_HOWTO = "https://howto.disroot.org";
    public static final String URL_DisApp_K9HELP = "https://howto.disroot.org/en/communication/email/clients/mobile/k9";
    public static final String URL_DisApp_XMPPHELP = "https://howto.disroot.org/en/communication/chat/mobile/android/conversation";
    public static final String URL_DisApp_SEARXHELP = "https://disroot.org/services/search";
    public static final String URL_DisApp_STATEXMPP = "xmpp:state@chat.disroot.org?join";
    public static final String URL_DisApp_STATEMATRIX = "https://matrix.to/#/#state:disroot.org";
    public static final String URL_DisApp_STATESOCIAL = "https://hub.disroot.org/channel/disroot_state";
    public static final String URL_DisApp_STATENEWS = "https://state.disroot.org/subscribe";
    public static final String URL_DisApp_STATERSS = "https://state.disroot.org/atom";


    public static final String URL_LICENSE = "https://www.gnu.org/licenses/lgpl-3.0.en.html";
    public static final String URL_DISROOT = "https://disroot.org";
    public static final String URL_FDROID = "https://f-droid.org/FDroid.apk";
    public static final String URL_DIO = "https://github.com/renancunha33/DiolinuxApp";
    public static final String URL_TRANSLATE = "https://git.fosscommunity.in/disroot/disapp";
    public static final String URL_SOURCE = "https://git.fosscommunity.in/disroot/disapp";
    public static final String URL_BUGS = "https://git.fosscommunity.in/disroot/disapp/issues";
    public static final String URL_XMPP = "xmpp:disroot@chat.disroot.org?join";
    public static final String URL_SUPPORT = "mailto:support@disroot.org";
    public static final String URL_DisApp_CLOUDHELP = "https://howto.disroot.org/en/cloud/clients/mobile/android/nextcloud-app";
    public static final String URL_DisApp_DIAHELP = "https://disroot.org/services/diaspora";
    public static final String URL_DisApp_FORUMHELP = "https://howto.disroot.org/en/communication/forum";
    public static final String URL_DisApp_PADHELP = "https://howto.disroot.org/en/projects_office/pads/etherpad";
    public static final String URL_DisApp_CALCHELP = "https://howto.disroot.org/en/projects_office/pads/ethercalc";
    public static final String URL_DisApp_BINHELP = "https://howto.disroot.org/en/projects_office/bin";
    public static final String URL_DisApp_UPLOADHELP = "https://howto.disroot.org/en/projects_office/lufi";
    public static final String URL_DisApp_POLLHELP = "https://howto.disroot.org/en/projects_office/polls";
    public static final String URL_DisApp_BOARDHELP = "https://howto.disroot.org/en/cloud/apps/notes/mobile";
    public static final String URL_DisApp_NOTESHELP = "https://howto.disroot.org/en/nextcloud/sync-with-your-cloud/android/using-notes";
}

==> v1.2.0.zip: disapp/app/src/main/java/org/disroot/disrootapp/utils/Constants.java <==
package org.disroot.disrootapp.utils;

/**
 * Created by jackson on 02/11/15.
 */
public class Constants {
    public static final long SPLASH_SCREEN_DURATION = 3000;
    public static final long SPLASH_SCREEN_INTERVAL = 1000;


    public static final String title_activity_state = "StateActivity";
    public static final String URL_DisApp_FORUM = "https://forum.disroot.org/";
    public static final String URL_DisApp_CALC = "https://calc.disroot.org";
    public static final String URL_DisApp_BIN = "https://bin.disroot.org";
    public static final String URL_DisApp_UPLOAD = "https://upload.disroot.org";
    public static final String URL_DisApp_SEARX = "https://search.disroot.org";
    public static final String URL_DisApp_POLL = "https://poll.disroot.org";
    public static final String URL_DisApp_BOARD = "https://board.disroot.org";
    public static final String URL_DisApp_USER = "https://user.disroot.org";
    public static final String URL_DisApp_HOWTO = "https://howto.disroot.org";
    public static final String URL_DisApp_K9HELP = "https://howto.disroot.org/en/communication/email/clients/mobile/k9";
    public static final String URL_DisApp_XMPPHELP = "https://howto.disroot.org/en/communication/chat/mobile/android/conversations";
    public static final String URL_DisApp_SEARXHELP = "https://disroot.org/services/search";
    public static final String URL_DisApp_STATEXMPP = "xmpp:state@chat.disroot.org?join";
    public static final String URL_DisApp_STATEMATRIX = "https://matrix.to/#/#state:disroot.org";
    public static final String URL_DisApp_STATESOCIAL = "https://hub.disroot.org/channel/disroot_state";
    public static final String URL_DisApp_STATENEWS = "https://state.disroot.org/subscribe";
    public static final String URL_DisApp_STATERSS = "https://state.disroot.org/atom";


    public static final String URL_LICENSE = "https://www.gnu.org/licenses/lgpl-3.0.en.html";
    public static final String URL_DISROOT = "https://disroot.org";
    public static final String URL_FDROID = "https://f-droid.org/FDroid.apk";
    public static final String URL_DIO = "https://github.com/renancunha33/DiolinuxApp";
    public static final String URL_TRANSLATE = "https://git.fosscommunity.in/disroot/disapp";
    public static final String URL_SOURCE = "https://git.fosscommunity.in/disroot/disapp";
    public static final String URL_BUGS = "https://git.fosscommunity.in/disroot/disapp/issues";
    public static final String URL_XMPP = "xmpp:disroot@chat.disroot.org?join";
    public static final String URL_SUPPORT = "mailto:support@disroot.org";
    public static final String URL_DisApp_CLOUDHELP = "https://howto.disroot.org/en/cloud/clients/mobile/android/nextcloud-app";
    public static final String URL_DisApp_DIAHELP = "https://disroot.org/services/diaspora";
    public static final String URL_DisApp_FORUMHELP = "https://howto.disroot.org/en/communication/forum";
    public static final String URL_DisApp_PADHELP = "https://howto.disroot.org/en/projects_office/pads/etherpad";
    public static final String URL_DisApp_CALCHELP = "https://howto.disroot.org/en/projects_office/pads/ethercalc";
    public static final String URL_DisApp_BINHELP = "https://howto.disroot.org/en/projects_office/bin";
    public static final String URL_DisApp_UPLOADHELP = "https://howto.disroot.org/en/projects_office/lufi";
    public static final String URL_DisApp_POLLHELP = "https://howto.disroot.org/en/projects_office/polls";
    public static final String URL_DisApp_BOARDHELP = "https://howto.disroot.org/en/cloud/apps/notes/mobile";
    public static final String URL_DisApp_NOTESHELP = "https://howto.disroot.org/en/nextcloud/sync-with-your-cloud/android/using-notes";
}
